==> nodejs_0.4.9.orig.tar.gz: node-v0.4.9/test/simple/test-http-response-close.js <==
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

var common = require('../common');
var assert = require('assert');
var http = require('http');

var gotEnd = false;

var server = http.createServer(function(req, res) {
  res.writeHead(200);
  res.write('a');

  req.on('close', function() {
    console.error("aborted");
    gotEnd = true;
  });
});
server.listen(common.PORT);

server.addListener('listening', function() {
  console.error("make req");
  http.get({
    port: common.PORT
  }, function(res) {
    console.error("got res");
    res.on('data', function(data) {
      console.error("destroy res");
      res.destroy();
      server.close();
    });
  });
});

process.on('exit', function() {
  assert.ok(gotEnd);
});

==> nodejs_0.10.25~dfsg2.orig.tar.gz: node-v0.10.25~dfsg2/test/simple/test-http-response-close.js <==
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

var common = require('../common');
var assert = require('assert');
var http = require('http');

var requestGotEnd = false;
var responseGotEnd = false;

var server = http.createServer(function(req, res) {
  res.writeHead(200);
  res.write('a');

  req.on('close', function() {
    console.error('request aborted');
    requestGotEnd = true;
  });
  res.on('close', function() {
    console.error('response aborted');
    responseGotEnd = true;
  });
});
server.listen(common.PORT);

server.on('listening', function() {
  console.error('make req');
  http.get({
    port: common.PORT
  }, function(res) {
    console.error('got res');
    res.on('data', function(data) {
      console.error('destroy res');
      res.destroy();
      server.close();
    });
  });
});

process.on('exit', function() {
  assert.ok(requestGotEnd);
  assert.ok(responseGotEnd);
});
